@@ -113,9 +113,6 @@ pub enum SubclassSelector {
 
     #[tag("PseudoElementSelector")]
     PseudoElement(PseudoElementSelector),
-
-    #[tag("AtSelector")]
-    At(AtSelector),
 }
 
 #[ast_node("IdSelector")]
@@ -197,13 +194,6 @@ pub struct PseudoElementSelector {
     pub children: Option<Tokens>,
 }
 
-/// Type for `@top-center`. Allowwed in only some contexts.
-#[ast_node("AtSelector")]
-pub struct AtSelector {
-    pub span: Span,
-    pub text: Ident,
-}
-
 #[ast_node]
 pub enum PseudoSelectorChildren {
     #[tag("Nth")]
